import numpy as np
import matplotlib.pyplot as plt
from sklearn.model_selection import train_test_split
from sklearn.linear_model import LogisticRegression

# Leo los primeros 100 renglones
A = np.loadtxt( "iris.csv", delimiter=',', skiprows=1, usecols=(0,1,4), max_rows=100  ) 

# Vamos a usar las dos primeras columnas y las dos
# primeras clases

X = A[:, 0:2] 
y = A[:, 2] 

print ( X.shape )
print ( y.shape )

# Separamos los datos de entrenamiento y de prubea

X_entrena, X_prueba, y_entrena, y_prueba = train_test_split( X, y, random_state=21 )

print( X_entrena.shape )
print( y_entrena.shape )


# Construimos el modelo
clasificador = LogisticRegression( random_state=2 ) 

clasificador.fit( X_entrena, y_entrena )

exactitud_entrena = clasificador.score( X_entrena, y_entrena )
exactitud_prueba  = clasificador.score( X_prueba, y_prueba )

print( "Exactitud de entrenamiento:", exactitud_entrena )
print( "Exactitud de prueba:", exactitud_prueba )

# Hacemos la gráfica de los datos
fig, [ax1, ax2] = plt.subplots(nrows=1, ncols=2 )

ax1.scatter( X_entrena[:,0], X_entrena[:,1], c=y_entrena )
ax1.set_xlim( 4, 7.2 )
ax1.set_ylim( 1.8, 4.6 )

ax2.scatter( X_prueba[:,0], X_prueba[:,1], c=y_prueba )
ax2.set_xlim( 4, 7.2 )
ax2.set_ylim( 1.8, 4.6 )

plt.show( )


print( clasificador.coef_)
print( clasificador.intercept_ )
